# RELENT
Linter for for our new [release engine hotness](https://github.com/RHInception/?query=re-).

[![Build Status](https://api.travis-ci.org/RHInception/relent.png)](https://travis-ci.org/RHInception/relent/)

For documentation see the [Read The Docs](http://release-engine.readthedocs.org/en/latest/libraries/relent.html) documentation.
